"""
Init for main richie openedx synchronization application
"""
from __future__ import unicode_literals

__version__ = "1.0.0"

default_app_config = 'richie_openedx_sync.apps.RichieOpenEdxSyncConfig'
